require 'rails_helper'

module EmmetNotifications
  describe Message, type: :model do
    context 'validations' do
      it { is_expected.to validate_presence_of(:kind) }
      it { is_expected.to validate_inclusion_of(:kind).in_array(MessageType.list) }
      it { is_expected.to validate_presence_of(:title) }
      it { is_expected.to validate_presence_of(:slug) }
      it { is_expected.to validate_presence_of(:subject) }
      it { is_expected.to validate_presence_of(:description) }
      it { is_expected.to validate_presence_of(:content) }
    end

    context 'attributes' do
      it { is_expected.to have_db_column(:title).of_type(:string) }
      it { is_expected.to have_db_column(:slug).of_type(:string) }
      it { is_expected.to have_db_column(:kind).of_type(:integer) }
      it { is_expected.to have_db_column(:subject).of_type(:string) }
      it { is_expected.to have_db_column(:description).of_type(:text) }
      it { is_expected.to have_db_column(:content).of_type(:text) }
      it { is_expected.to have_db_column(:deleted_at).of_type(:datetime) }
    end

    context :send_to do
      let(:message) { Message.new(subject: 'Rspec Mail', content: 'Hi {{name}}, are you ok?') }
      let(:email) { 'test@example.com' }

      it 'should return Mail::Message' do
        expect(message.send_to(email, name: 'Tester').class).to eq Mail::Message
      end
    end

    context 'send_to_by slug' do
      let(:message) { Message.create!(title: 'Title message', subject: 'Rspec Mail', description: 'Description Message', content: 'Hi {{name}}, are you ok?') }
      let(:email) { 'test@example.com' }

      it { expect(message.slug).to eq 'title_message' }

      it 'should return Mail::Message' do
        expect(Message.send_to_by(message.slug, email, name: 'Tester').class).to eq Message
      end
    end

    context 'set slug' do
      let(:message) { Message.new title: 'Title message' }

      it 'when title "Title message" slug should eq "title_message"' do
        message.valid?
        expect(message.slug).to eq('title_message')
      end
    end
  end
end
